fuel_
core_
executor
0.41.7
Module executor
Module Items
Structs
Functions
In crate fuel_
core_
executor
fuel_core_executor
Module
executor
Structs

Block
Executor
Execution
Data
Data that is generated after executing all transactions.
Execution
Instance
The executor instance performs block production and validation. Given a block, it will execute all the transactions contained in the block and persist changes to the underlying database as needed.
Execution
Options
Per-block execution options
Once
Transactions
Functions

max_
tx_
count
The maximum amount of transactions that can be included in a block, excluding the mint transaction.