Struct fuel_core_executor::refs::ContractRef
source · pub struct ContractRef<Database> { /* private fields */ }Expand description
The wrapper around contract_id to simplify work with Contract in the database.
pub struct ContractRef<Database> { /* private fields */ }The wrapper around contract_id to simplify work with Contract in the database.