Module fuel_core_executor::executor
source · Modules
Structs
- Data that is generated after executing all transactions.
- The executor instance performs block production and validation. Given a block, it will execute all the transactions contained in the block and persist changes to the underlying database as needed. In production mode, block fields like transaction commitments are set based on the executed txs. In validation mode, the processed block commitments are compared with the proposed block.
- Per-block execution options